@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window::Tk;
-$App::ClusterSSH::Window::Tk::VERSION = '4.16';
+$App::ClusterSSH::Window::Tk::VERSION = '4.18';
 # ABSTRACT: Object for creating windows using Tk
 
 use English qw( -no_match_vars );
@@ -10,8 +10,8 @@ use English qw( -no_match_vars );
 use base qw/ App::ClusterSSH::Base /;
 use vars qw/ %keysymtocode %keycodetosym /;
 
-use Net::Domain qw(hostfqdn);
-use File::Temp qw/:POSIX/;
+use Sys::Hostname qw/ hostname /;
+use File::Temp    qw/:POSIX/;
 use Fcntl;
 use POSIX ":sys_wait_h";
 use POSIX qw/:sys_wait_h strftime mkfifo/;
@@ -27,14 +27,14 @@ use X11::Protocol::Constants qw/ Shift Mod5 ShiftMask /;
 use X11::Protocol::WM 29;
 use X11::Keysyms '%keysymtocode', 'MISCELLANY', 'XKB_KEYS', '3270', 'LATIN1',
     'LATIN2', 'LATIN3', 'LATIN4', 'KATAKANA', 'ARABIC', 'CYRILLIC', 'GREEK',
-    'TECHNICAL', 'SPECIAL', 'PUBLISHING', 'APL', 'HEBREW', 'THAI', 'KOREAN';
+    'TECHNICAL', 'SPECIAL', 'PUBLISHING', 'APL', 'HEBREW', 'THAI',  'KOREAN';
 
 # Module to contain all Tk specific functionality
 
-my %windows;    # hash for all window definitions
-my %menus;      # hash for all menu definitions
-my @servers;    # array of servers provided on cmdline
-my %servers;    # hash of server cx info
+my %windows;                   # hash for all window definitions
+my %menus;                     # hash for all menu definitions
+my @servers;                   # array of servers provided on cmdline
+my %servers;                   # hash of server cx info
 my $xdisplay;
 my %keyboardmap;
 my $sysconfigdir = "/etc";
@@ -185,8 +185,8 @@ sub open_client_windows(@) {
         $servers{$server}{realname}       = $realname;
         $servers{$server}{username}       = $self->config->{user};
         $servers{$server}{username}       = $username if ($username);
-        $servers{$server}{username}       = $username || '';
-        $servers{$server}{port}           = $port || '';
+        $servers{$server}{username}       = $username             || '';
+        $servers{$server}{port}           = $port                 || '';
         $servers{$server}{master}         = $self->config->{mstr} || '';
         $servers{$server}{master}         = $master if ($master);
 
@@ -436,8 +436,9 @@ sub load_keyboard_map() {
 
                 # keyboard layout contains the keycode at $modifier level
                 if (defined(
-                        $keyboardmap{ $keycodetosym{ $keyboard[$i][$modifier]
-                        } }
+                        $keyboardmap{
+                            $keycodetosym{ $keyboard[$i][$modifier] }
+                        }
                     )
                     )
                 {
@@ -602,7 +603,7 @@ sub substitute_macros {
     }
     {
         my $macro_hostname = $self->config->{macro_hostname};
-        my $hostname       = hostfqdn();
+        my $hostname       = $self->config->{hostname_override} || hostname();
         $text =~ s!$macro_hostname!$hostname!xsmg;
         $ENV{CSSH_HOSTNAME} = $hostname;
     }
@@ -1279,11 +1280,18 @@ sub setup_repeat() {
 ### Window and menu definitions ###
 
 sub create_windows() {
-    my ($self) = @_;
+    my ($self)          = @_;
+    my ($screen_height) = $xdisplay->{height_in_pixels};
+    my ($screen_width)  = $xdisplay->{width_in_pixels};
     $self->debug( 2, "create_windows: started" );
 
     $windows{main_window}
         = MainWindow->new( -title => "ClusterSSH", -class => 'cssh', );
+    if ( $screen_height * $screen_width >= 8294400 )    # display 4k or bigger
+    {
+        $windows{main_window}->optionAdd( '*font', 'Nimbus 14' )
+            ;    # better for 4k displays
+    }
     $windows{main_window}->withdraw;    # leave withdrawn until needed
 
     if ( defined( $self->config->{console_position} )
@@ -1562,7 +1570,7 @@ sub key_event {
     my $keycode   = $Tk::event->k;
     my $keysymdec = $Tk::event->N;
     my $keysym    = $Tk::event->K;
-    my $state = $Tk::event->s || 0;
+    my $state     = $Tk::event->s || 0;
 
     $menus{entrytext} = "";
 
